# Resource

Here is a list of available actions for Data Resource

- `check_package` -- check the descriptor against JSON Schema(s)
- `convert_package` -- convert the descriptor from one notation to another

## Reference

::: dplib.actions.resource.check.check_resource
::: dplib.actions.resource.convert.convert_resource
